@@ -88,6 +88,13 @@ def parse_arguments():
         default=0,
         help='MACS2 shift (use -100 for ATAC-seq) [0]'
     )
+    macs2_group.add_argument(
+        '--extsize',
+        metavar='<int>',
+        type=int,
+        default=200,
+        help='MACS2 extsize [200]'
+    )
     macs2_group.add_argument(
         '--color',
         metavar='<color>',
@@ -154,6 +161,7 @@ def main():
 	        broad_cutoff=args.broad_cutoff,
             nomodel=args.nomodel,
             shift=args.shift,
+            extsize=args.extsize,
 	        log=f,
             temp_dir=args.tmp_dir
         )
